--- servers/slapd/acl.c.orig	2008-01-28 12:50:02.000000000 -0600
+++ servers/slapd/acl.c	2008-01-28 12:52:03.000000000 -0600
@@ -16,7 +16,7 @@
 #include "slap.h"
 #include "sets.h"
 
-static AccessControl * acl_get(
+static AccessControl * slapd_acl_get(
 	AccessControl *ac, int *count,
 	Backend *be, Operation *op,
 	Entry *e,
@@ -167,7 +167,7 @@
 	a = NULL;
 	count = 0;
 
-	while((a = acl_get( a, &count, be, op, e, desc, MAXREMATCHES, matches )) != NULL)
+	while((a = slapd_acl_get( a, &count, be, op, e, desc, MAXREMATCHES, matches )) != NULL)
 	{
 		int i;
 
@@ -216,13 +216,13 @@
 }
 
 /*
  * acl_get - return the acl applicable to entry e, attribute
  * attr.  the acl returned is suitable for use in subsequent calls to
  * acl_access_allowed().
  */
 
 static AccessControl *
-acl_get(
+slapd_acl_get(
 	AccessControl *a,
 	int			*count,
     Backend		*be,
@@ -314,7 +314,7 @@
 					continue;
 			}
 
-			Debug( LDAP_DEBUG_ACL, "=> acl_get: [%d] matched\n",
+			Debug( LDAP_DEBUG_ACL, "=> slapd_acl_get: [%d] matched\n",
 				*count, 0, 0 );
 		}
 
@@ -325,21 +325,21 @@
 			}
 		}
 
-        Debug( LDAP_DEBUG_ACL, "=> acl_get: [%d] check attr %s\n",
+        Debug( LDAP_DEBUG_ACL, "=> slapd_acl_get: [%d] check attr %s\n",
 			*count, attr, 0);
 
 		if ( attr == NULL || a->acl_attrs == NULL ||
 			ad_inlist( desc, a->acl_attrs ) )
 		{
 			Debug( LDAP_DEBUG_ACL,
-				"<= acl_get: [%d] acl %s attr: %s\n",
+				"<= slapd_acl_get: [%d] acl %s attr: %s\n",
 				*count, e->e_dn, attr );
 			return a;
 		}
 		matches[0].rm_so = matches[0].rm_eo = -1;
 	}
 
-	Debug( LDAP_DEBUG_ACL, "<= acl_get: done.\n", 0, 0, 0 );
+	Debug( LDAP_DEBUG_ACL, "<= slapd_acl_get: done.\n", 0, 0, 0 );
 	return( NULL );
 }
 
@@ -216,13 +216,13 @@
 
 /*
- * acl_get - return the acl applicable to entry e, attribute
+ * slapd_acl_get - return the acl applicable to entry e, attribute
  * attr.  the acl returned is suitable for use in subsequent calls to
  * acl_access_allowed().
